==> gsequencer_2.1.53.orig.tar.gz: gsequencer-2.1.53/ags/audio/task/ags_crop_note.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2018 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_CROP_NOTE_H__
#define __AGS_CROP_NOTE_H__

#include <glib.h>
#include <glib-object.h>

#include <ags/libags.h>

#include <ags/audio/ags_audio.h>
#include <ags/audio/ags_notation.h>

#define AGS_TYPE_CROP_NOTE                (ags_crop_note_get_type())
#define AGS_CROP_NOTE(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_CROP_NOTE, AgsCropNote))
#define AGS_CROP_NOTE_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST((class), AGS_TYPE_CROP_NOTE, AgsCropNoteClass))
#define AGS_IS_CROP_NOTE(obj)             (G_TYPE_CHECK_INSTANCE_TYPE((obj), AGS_TYPE_CROP_NOTE))
#define AGS_IS_CROP_NOTE_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE((class), AGS_TYPE_CROP_NOTE))
#define AGS_CROP_NOTE_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS((obj), AGS_TYPE_CROP_NOTE, AgsCropNoteClass))

#define AGS_CROP_NOTE_DEFAULT_X_LENGTH (16 * 16 * 1200)

typedef struct _AgsCropNote AgsCropNote;
typedef struct _AgsCropNoteClass AgsCropNoteClass;

struct _AgsCropNote
{
  AgsTask task;

  AgsAudio *audio;
  AgsNotation *notation;

  GList *selection;
  
  guint x_padding;
  gint x_crop;
  
  gboolean absolute;
  gboolean in_place;
  gboolean do_resize;
};

struct _AgsCropNoteClass
{
  AgsTaskClass task;
};

GType ags_crop_note_get_type();

AgsCropNote* ags_crop_note_new(AgsNotation *notation,
			       GList *selection,
			       guint x_padding, gint x_crop,
			       gboolean absolute, gboolean in_place, gboolean do_resize);

#endif /*__AGS_CROP_NOTE_H__*/

==> gsequencer_3.1.3.orig.tar.gz: gsequencer-3.1.3/ags/audio/task/ags_crop_note.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2019 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_CROP_NOTE_H__
#define __AGS_CROP_NOTE_H__

#include <glib.h>
#include <glib-object.h>

#include <ags/libags.h>

#include <ags/audio/ags_audio.h>
#include <ags/audio/ags_notation.h>

G_BEGIN_DECLS

#define AGS_TYPE_CROP_NOTE                (ags_crop_note_get_type())
#define AGS_CROP_NOTE(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_CROP_NOTE, AgsCropNote))
#define AGS_CROP_NOTE_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST((class), AGS_TYPE_CROP_NOTE, AgsCropNoteClass))
#define AGS_IS_CROP_NOTE(obj)             (G_TYPE_CHECK_INSTANCE_TYPE((obj), AGS_TYPE_CROP_NOTE))
#define AGS_IS_CROP_NOTE_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE((class), AGS_TYPE_CROP_NOTE))
#define AGS_CROP_NOTE_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS((obj), AGS_TYPE_CROP_NOTE, AgsCropNoteClass))

#define AGS_CROP_NOTE_DEFAULT_X_LENGTH (16 * 16 * 1200)

typedef struct _AgsCropNote AgsCropNote;
typedef struct _AgsCropNoteClass AgsCropNoteClass;

struct _AgsCropNote
{
  AgsTask task;

  AgsAudio *audio;
  AgsNotation *notation;

  GList *selection;
  
  guint x_padding;
  gint x_crop;
  
  gboolean absolute;
  gboolean in_place;
  gboolean do_resize;
};

struct _AgsCropNoteClass
{
  AgsTaskClass task;
};

GType ags_crop_note_get_type();

AgsCropNote* ags_crop_note_new(AgsAudio *audio,
			       AgsNotation *notation,
			       GList *selection,
			       guint x_padding, gint x_crop,
			       gboolean absolute, gboolean in_place, gboolean do_resize);

G_END_DECLS

#endif /*__AGS_CROP_NOTE_H__*/
